@@ -3,18 +3,18 @@ package exact::cli;
 
 use 5.014;
 use exact;
-use strict;
 use Util::CommandLine 1.04 ();
 
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 
 sub import {
-    my ( $self, $caller ) = @_;
+    my ( $self, $params, $caller ) = @_;
     $caller //= caller();
 
     my @methods = qw( options pod2usage readmode singleton );
     {
         no strict 'refs';
+
         for (@methods) {
             my $method = "Util::CommandLine::$_";
             *{ $caller . '::' . $_ } = \&$method unless ( defined &{ $caller . '::' . $_ } );
@@ -44,7 +44,7 @@ exact::cli - Command-line interface helper utilities extension for exact
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =for markdown [![test](https://github.com/gryphonshafer/exact-cli/workflows/test/badge.svg)](https://github.com/gryphonshafer/exact-cli/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/exact-cli/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/exact-cli)
